==> jc-1.4.0.tar.gz: polyglot/types/SemanticException.h <==
// public class polyglot.types.SemanticException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 45f755f5298b5b39 polyglot_types_SemanticException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_polyglot_types_SemanticException_H_
#define _JC_polyglot_types_SemanticException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_types_SemanticException$sub_refs	_jc_polyglot_types_SemanticException$sub_refs;
typedef struct _jc_polyglot_types_SemanticException$sub_nonrefs	_jc_polyglot_types_SemanticException$sub_nonrefs;
typedef struct _jc_polyglot_types_SemanticException$refs	_jc_polyglot_types_SemanticException$refs;
typedef struct _jc_polyglot_types_SemanticException$nonrefs	_jc_polyglot_types_SemanticException$nonrefs;
typedef struct _jc_polyglot_types_SemanticException$object	_jc_polyglot_types_SemanticException$object;

typedef const struct _jc_polyglot_types_SemanticException$vmethods	_jc_polyglot_types_SemanticException$vmethods;
typedef const struct _jc_polyglot_types_SemanticException$vtable	_jc_polyglot_types_SemanticException$vtable;
typedef const struct _jc_polyglot_types_SemanticException$vtype	_jc_polyglot_types_SemanticException$vtype;

// Constructors
extern void _jc_polyglot_types_SemanticException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_types_SemanticException$object *);
extern void _jc_polyglot_types_SemanticException$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_types_SemanticException$object *, struct _jc_java_lang_String$object *);
extern void _jc_polyglot_types_SemanticException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_polyglot_types_SemanticException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *);
extern void _jc_polyglot_types_SemanticException$method$_init$554f76f5bea40c52(_jc_env *, struct _jc_polyglot_types_SemanticException$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_util_Position$object *);
extern void _jc_polyglot_types_SemanticException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_polyglot_types_SemanticException$object *, struct _jc_java_lang_Throwable$object *);
extern void _jc_polyglot_types_SemanticException$method$_init$02a94c1d4b5cc142(_jc_env *, struct _jc_polyglot_types_SemanticException$object *, struct _jc_polyglot_util_Position$object *);

// Virtual methods
extern struct _jc_polyglot_util_Position$object *_jc_polyglot_types_SemanticException$method$position$bb89333b1e4c840c(_jc_env *, struct _jc_polyglot_types_SemanticException$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_SemanticException$method_info$position$bb89333b1e4c840c;

// Static methods
extern void _jc_polyglot_types_SemanticException$method$trace$92cfa6debf531161(_jc_env *, struct _jc_java_lang_Exception$object *, jint);

// Virtual methods structure
struct _jc_polyglot_types_SemanticException$vmethods {
	struct _jc_polyglot_util_Position$object	*(*position$bb89333b1e4c840c)(_jc_env *, struct _jc_polyglot_types_SemanticException$object *);
};

// Vtable
struct _jc_polyglot_types_SemanticException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_polyglot_types_SemanticException$vmethods	polyglot_types_SemanticException;
};

// Vtype
struct _jc_polyglot_types_SemanticException$vtype {
	_jc_type			type;
	_jc_polyglot_types_SemanticException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_SemanticException$sub_refs {
	struct _jc_polyglot_util_Position$object	*position;
};

// Reference instance fields (object)
struct _jc_polyglot_types_SemanticException$refs {
    _jc_polyglot_types_SemanticException$sub_refs	polyglot_types_SemanticException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_SemanticException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_SemanticException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_polyglot_types_SemanticException$sub_nonrefs	polyglot_types_SemanticException;
};

// Object instance structure
struct _jc_polyglot_types_SemanticException$object {
	_jc_polyglot_types_SemanticException$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_SemanticException$vtype	*vtype;
	_jc_polyglot_types_SemanticException$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_SemanticException$vtype _jc_polyglot_types_SemanticException$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_SemanticException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_SemanticException$class_object;

#endif	/* _JC_polyglot_types_SemanticException_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/SemanticException.h <==
// public class polyglot.types.SemanticException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 45f755f5298b5b39 polyglot_types_SemanticException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_polyglot_types_SemanticException_H_
#define _JC_polyglot_types_SemanticException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_types_SemanticException$sub_refs	_jc_polyglot_types_SemanticException$sub_refs;
typedef struct _jc_polyglot_types_SemanticException$sub_nonrefs	_jc_polyglot_types_SemanticException$sub_nonrefs;
typedef struct _jc_polyglot_types_SemanticException$refs	_jc_polyglot_types_SemanticException$refs;
typedef struct _jc_polyglot_types_SemanticException$nonrefs	_jc_polyglot_types_SemanticException$nonrefs;
typedef struct _jc_polyglot_types_SemanticException$object	_jc_polyglot_types_SemanticException$object;

typedef const struct _jc_polyglot_types_SemanticException$vmethods	_jc_polyglot_types_SemanticException$vmethods;
typedef const struct _jc_polyglot_types_SemanticException$vtable	_jc_polyglot_types_SemanticException$vtable;
typedef const struct _jc_polyglot_types_SemanticException$vtype	_jc_polyglot_types_SemanticException$vtype;

// Constructors
extern void _jc_polyglot_types_SemanticException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_types_SemanticException$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_types_SemanticException$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_types_SemanticException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_types_SemanticException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_polyglot_types_SemanticException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_types_SemanticException$method$_init$554f76f5bea40c52(_jc_env *, struct _jc_polyglot_types_SemanticException$object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_types_SemanticException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_polyglot_types_SemanticException$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_types_SemanticException$method$_init$02a94c1d4b5cc142(_jc_env *, struct _jc_polyglot_types_SemanticException$object *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_util_Position$object *_jc_polyglot_types_SemanticException$method$position$bb89333b1e4c840c(_jc_env *, struct _jc_polyglot_types_SemanticException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_SemanticException$method_info$position$bb89333b1e4c840c;

// Static methods
extern void _jc_polyglot_types_SemanticException$method$trace$92cfa6debf531161(_jc_env *, struct _jc_java_lang_Exception$object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_types_SemanticException$vmethods {
	struct _jc_polyglot_util_Position$object	*(*position$bb89333b1e4c840c)(_jc_env *, struct _jc_polyglot_types_SemanticException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_types_SemanticException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_polyglot_types_SemanticException$vmethods	polyglot_types_SemanticException;
};

// Vtype
struct _jc_polyglot_types_SemanticException$vtype {
	_jc_type			type;
	_jc_polyglot_types_SemanticException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_SemanticException$sub_refs {
	struct _jc_polyglot_util_Position$object	*position;
};

// Reference instance fields (object)
struct _jc_polyglot_types_SemanticException$refs {
    _jc_polyglot_types_SemanticException$sub_refs	polyglot_types_SemanticException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_SemanticException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_SemanticException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_polyglot_types_SemanticException$sub_nonrefs	polyglot_types_SemanticException;
};

// Object instance structure
struct _jc_polyglot_types_SemanticException$object {
	_jc_polyglot_types_SemanticException$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_SemanticException$vtype	*vtype;
	_jc_polyglot_types_SemanticException$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_SemanticException$vtype _jc_polyglot_types_SemanticException$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_SemanticException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_SemanticException$class_object;

#endif	/* _JC_polyglot_types_SemanticException_H_ */
